
``plone.app.layoutpage`` provides a very basic page content type for Plone
that is editable via Deco.


Changelog
=========

1.1 (2012-12-17)
----------------

- flake8 on code
  [garbas]

- possibility to add "page" content type as default page and marking it as
  folderish for TinyMCE
  [garbas]

- use deco grid classes
  [davisagli]

- use classes and only one column, row by default
  [vangheem]

1.0 (2012-06-23)
----------------

- initial release.
  [garbas]
